pub struct LengthPrefixed { /* private fields */ }Expand description
Length-prefixed framer.
Example
use wire_codec::WriteBuf;
use wire_codec::framing::{Endian, Framer, LengthPrefixed, LengthWidth};
let framer = LengthPrefixed::new(LengthWidth::U16, Endian::Big);
let mut out = [0u8; 16];
let mut buf = WriteBuf::new(&mut out);
framer.write_frame(b"hello", &mut buf).unwrap();
let written = buf.position();
assert_eq!(&out[..written], &[0x00, 0x05, b'h', b'e', b'l', b'l', b'o']);
let frame = framer.next_frame(&out[..written]).unwrap().unwrap();
assert_eq!(frame.payload(), b"hello");
assert_eq!(frame.consumed(), 7);Implementations
Sourceimpl LengthPrefixed
impl LengthPrefixed
Sourcepub const fn new(width: LengthWidth, endian: Endian) -> Self
pub const fn new(width: LengthWidth, endian: Endian) -> Self
Build a framer using the given prefix width and endianness.
The maximum payload size defaults to the largest value the prefix can
encode. Use LengthPrefixed::with_max_payload to tighten it.
Sourcepub const fn with_max_payload(self, max: u64) -> Self
pub const fn with_max_payload(self, max: u64) -> Self
Override the payload size limit enforced when reading and writing frames.
The limit is clamped to LengthWidth::max_payload of the configured
width.
Sourcepub const fn width(&self) -> LengthWidth
pub const fn width(&self) -> LengthWidth
Configured prefix width.
Sourcepub const fn max_payload(&self) -> u64
pub const fn max_payload(&self) -> u64
Configured maximum payload size in bytes.